@@ -81,8 +81,8 @@ end
     for i in 790 : 810
         A = wilkinson(i)
         b = rand(i)
-        ws = RecursiveFactorization.🦋workspace(copy(A), copy(b))    
-        out = RecursiveFactorization.🦋lu!(ws, i, Val(true))
+        ws = RecursiveFactorization.🦋workspace(copy(A), copy(b))
+        out = RecursiveFactorization.🦋solve!(ws, Val(true))
         @test norm(A * out .- b) <= 1e-10
     end
 end
